import { client, lang, navigateTo } from "../index.js";
import { clear, fill_errors } from "../utils/formUtils.js";
import AbstractAuthenticatedView from "./abstracts/AbstractAuthenticatedView.js";

export default class extends AbstractAuthenticatedView {

    constructor(params)
    {
		super(params, "Matchmaking");
    }

    async toggle_search()
    {
        clear("innerText", ["detail"]);
        if (client.matchmaking.searching)
        {
            client.matchmaking.stop();
            this.button.innerHTML = lang.get("matchmakingStartSearch");
        }
        else
        {
            let nb_players = this.input.value;

            await client.matchmaking.start(this.onreceive.bind(this), this.ondisconnect.bind(this), nb_players);

            this.button.innerHTML = lang.get("matchmakingStopSearch");
        }
    }

    ondisconnect(event)
    {
        this.button.innerHTML = lang.get("matchmakingStartSearch");
    }

    onreceive(data)
    {
        if (data.detail === "game_found")
        {
            navigateTo(`/games/${data.game_id}`);
            return;
        }
        this.display_data(data);
    }

    display_data(data)
    {
        clear("innerText", ["detail"]);
        fill_errors(data, "innerText");
    }

    async postInit()
    {
        this.button = document.getElementById("toggle-search");
        this.input = document.getElementById("nb-players-input");
        
        this.button.onclick = this.toggle_search.bind(this);

        this.input.addEventListener('keydown', async ev => {

            if (ev.key !== 'Enter')
                return;

            await this.toggle_search.bind(this);
        });

        let update = () => {
            this.button.disabled = (this.input.value < 2 || this.input.value > 4);
        };

        ["change", "oninput"].forEach((event_name) => {
            this.input.addEventListener(event_name, update);
        });
    }

    async getHtml() {
        return /* HTML */ `
            <div class='container-fluid'>
                <div class='border border-2 rounded bg-light-subtle mx-auto p-2 col-md-7 col-lg-4'>
                    <h4 class='text-center fw-semibold mb-4' id="title">${lang.get("matchmakingTitle")}</h4>
                    <div class='form-floating mb-2'>
                        <input type='number' min='2' value='2' max='4' class='form-control' id='nb-players-input' placeholder='${lang.get("matchmakingNbPlayers")}'>
                        <label for='nb-players-input' id='username-label'>${lang.get("matchmakingNbPlayers")}</label>
                        <span class='text-danger' id='username'></span>
                    </div>
                    <div class='d-flex'>
                        <button type='button' class='btn btn-primary mt-3 mb-2 mx-2' id='toggle-search'>${lang.get("matchmakingStartSearch")}</button>
                        <span class='text-danger my-auto mx-2' id='detail'></span>
                    </div>
                </div>
            </div>
        `;
    }

    async leavePage()
    {
		await client.matchmaking.stop();
    }
}
